import vega from 'vega';
import vegaLite from 'vega-lite';
import vl from 'vega-lite-api';
import { Handler } from 'vega-tooltip';
import { config } from './config';
import { getData } from './getData';

import React, { Component, useState, useCallback } from 'react';
import ReactDOM from 'react-dom';

vl.register(vega, vegaLite, {
  view: { renderer: 'svg' },
  init: (view) => {
    view.tooltip(new Handler().call);
  },
});

function changeSelection() {
  console.log('test');
}

let newFilters = [];

class App extends Component {
  constructor() {
    super();

    let filters = [{ value: 'Microsoft Game Studios' }];
    this.state = {
      mark: null,
      filterText: this.getFilters(filters),
      selectedOption: null,
    };

    this.change = this.change.bind(this);
  }

  getFilters(filters) {
    var filterText = '';
    for (var i = 0; i < filters.length; i++) {
      if (i > 0) filterText += ' || ';
      filterText += 'datum.Publisher == "' + filters[i].value + '"';
    }
    return filterText;
  }

  // 	.transform(
  // 	vl.groupby('Year', colorField).aggregate(vl.count().as('Count')),
  // )

  async componentDidMount(isRecursive = false) {
    var viz = vl
      .markBar()
      .transform(
        
        vl.filter(this.state.filterText), 
        vl.groupby('Year').aggregate(vl.sum().field('Global_Sales').as('Sum_Sales'))
      )
      .encode(
        vl.x().fieldN('Year').title('Year'),
        vl.y().fieldQ('Sum_Sales').title('Total Global_Sales')
      );
    const data = await getData();

    const optionStrings = Array.from(new Set(data.map((d) => d.Publisher)));
    const options = optionStrings.map((string) => ({
      value: string,
      label: string,
    }));

    const marks = viz
      .data(data)
      .width(window.innerWidth)
      .height(window.innerHeight - 100)
      .autosize({ type: 'fit', contains: 'padding' })
      .config(config);

    //console.log(data[1000]);
    //options.push({value: data[0].Publisher, label: data[0].Publisher});

    const mark = await marks.render();
    this.setState({ mark: mark.innerHTML, options });
    if (!isRecursive) this.componentDidMount(true);
  }

  async change(selectedOption) {
    if (selectedOption.length == 0) return;

    this.setState({ selectedOption });
    console.log(`Option selected:`, selectedOption);

    this.setState({ filterText: this.getFilters(selectedOption) });

    this.componentDidMount();
  }

  render() {
    return (
      <div>
        <div id="menu-bar">
          {this.state.options ? (
            <Select
              defaultValue={this.state.options[0]}
              onChange={this.change}
              options={this.state.options}
              isMulti
            />
          ) : null}
        </div>
        <div dangerouslySetInnerHTML={{ __html: this.state.mark }} />
      </div>
    );
  }
}

export default App;
ReactDOM.render(<App />, document.getElementById('chart'));
